@@ -1,4 +1,6 @@
+import traceback
 from typing import Optional
+
 from rich.progress import Progress, TaskID
 from rich.spinner import Spinner
 
@@ -20,5 +22,9 @@ class RichProgressReporter:
 
     def finish(self, error: Optional[Exception] = None) -> None:
         if error:
-            self.bar.log(f"[red]{error}[/red]")
+            self.bar.log(
+                f"[red]"
+                + "\n".join(traceback.format_tb(error.__traceback__))
+                + "[/red]"
+            )
         self.bar.advance(self.task_id, 1)
