@@ -1,3 +1,4 @@
+from pathlib import Path
 from xml.etree.ElementTree import Element
 
 from eaw2web.gameobjecttypes import Faction
@@ -7,9 +8,9 @@ from eaw2web.xml.icon import icon_name
 from eaw2web.xml.text import text_or_empty
 
 
-def parse_faction(child: Element, encyclopedia: Encyclopedia):
+def parse_faction(file: Path, child: Element, encyclopedia: Encyclopedia) -> Faction:
     return Faction(
-        **(parse_generic_game_object(child, encyclopedia).dict()),
+        **(parse_generic_game_object(file, child, encyclopedia).dict()),
         icon=icon_name(child),
-        is_playable=bool_from_str(text_or_empty(child.find("Is_Playable")))
+        is_playable=bool_from_str(text_or_empty(child.find("Is_Playable"))),
     )
