@@ -1,7 +1,7 @@
 from xml.etree.ElementTree import Element
 
 
-def icon_name(child: Element):
+def icon_name(child: Element) -> str:
     icon_name_tag = child.find("Icon_Name")
 
     if icon_name_tag is not None and icon_name_tag.text is not None:
