@@ -1,3 +1,4 @@
+from pathlib import Path
 from xml.etree.ElementTree import Element
 
 from eaw2web.gameobjecttypes import Unit
@@ -7,9 +8,9 @@ from eaw2web.xml.icon import icon_name
 from eaw2web.xml.text import collect_tooltips, text_or_empty
 
 
-def parse_unit_object(child: Element, encyclopedia: Encyclopedia):
+def parse_unit_object(file: Path, child: Element, encyclopedia: Encyclopedia) -> Unit:
     return Unit(
-        **parse_generic_game_object(child, encyclopedia).dict(),
+        **parse_generic_game_object(file, child, encyclopedia).dict(),
         icon=icon_name(child),
         tooltips=collect_tooltips(child, encyclopedia),
         affiliation=affiliation(child),
@@ -17,7 +18,7 @@ def parse_unit_object(child: Element, encyclopedia: Encyclopedia):
     )
 
 
-def affiliation(child: Element):
+def affiliation(child: Element) -> list[str]:
     affiliation_text = text_or_empty(child.find("Affiliation"))
     split_affiliation = affiliation_text.split(",")
     return [
